package
Version:
v0.1.25
Opens a new window with list of versions in this module.
Published: Jul 19, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Of[T any](value T) *T
func OfOk[T any](value T, ok bool) *T
func Resolve[T any](value *T) T
func ResolveOr[T any](value *T, defaultValue T) T
func ResolveOrDefault[T any](value *T) T
Source Files
¶
Click to show internal directories.
Click to hide internal directories.